==> web-10.0.0.tgz: package/lib/myTable/tableList/TrItem.js <==
import * as React from "react";
import { SvgIcon } from "../../my-icon/index";
class TrItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            e.stopPropagation();
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const { changeState } = this.props;
            changeState(index, "active");
        };
    }
    getCheck() {
        const { node, index } = this.props;
        const active = node.get("checked") ? "checkbox-marked" : "checkbox-blank";
        return (React.createElement("span", { onClick: this.checkFn, className: "tree-check", "data-index": index },
            React.createElement(SvgIcon, { className: active })));
    }
    getFirstText(text, field) {
        const { index } = this.props;
        if (field === "order") {
            return index;
        }
        else if (field === "check") {
            return this.getCheck();
        }
        else {
            return text;
        }
    }
    render() {
        const { cols, node, fixObj: { tabField }, isMainView, } = this.props;
        const tds = cols.map((td, index) => {
            const { field, formatter, align } = td;
            const text = formatter
                ? formatter(node, index, tabField)
                : node.get(field);
            const str = isMainView ? this.getFirstText(text, field) : text;
            let alignName = align ? `td-${align}` : "";
            return (React.createElement("td", { key: field, className: `td-border ${alignName}` }, str));
        });
        return React.createElement("tr", null, tds);
    }
}
export default TrItem;

==> web-10.1.0.tgz: package/lib/myTable/tableList/TrItem.js <==
import * as React from "react";
import { SvgIcon } from "../../my-icon/index";
class TrItem extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.checkFn = (e) => {
            e.stopPropagation();
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const { changeState } = this.props;
            changeState(index, "active");
        };
    }
    getCheck() {
        const { node, index } = this.props;
        const active = node.get("checked") ? "checkbox-marked" : "checkbox-blank";
        return (React.createElement("span", { onClick: this.checkFn, className: "tree-check", "data-index": index },
            React.createElement(SvgIcon, { className: active })));
    }
    getFirstText(text, field) {
        const { index } = this.props;
        if (field === "order") {
            return index;
        }
        else if (field === "check") {
            return this.getCheck();
        }
        else {
            return text;
        }
    }
    render() {
        const { cols, node, fixObj: { tabField }, isMainView, } = this.props;
        const tds = cols.map((td, index) => {
            const { field, formatter, align } = td;
            const text = formatter
                ? formatter(node, index, tabField, field)
                : node.get(field);
            const str = isMainView ? this.getFirstText(text, field) : text;
            let alignName = align ? `${align}` : "";
            return (React.createElement("td", { key: field, "data-filed": field, className: `td-border ${alignName}` }, str));
        });
        return React.createElement("tr", null, tds);
    }
}
export default TrItem;
